[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --fast-version-control
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


# About git-scm.com
This site is open source and maintained by members of the Git community. We welcome patches, suggestions, and corrections.
## Open Source
The content on this site is pulled from multiple sources. It is available under various licenses, and bug reports should be directed to the appropriate repositories:
  * Most of the "base" site content is hosted in the [git/git-scm.com](https://github.com/git/git-scm.com) repository at GitHub. That includes all pages except the book and manpages, along with the general design of the site. This content is available under the [MIT license](https://github.com/git/git-scm.com/tree/gh-pages?tab=MIT-1-ov-file#readme). Bug reports and suggestions may be made in that repository.
  * Content from the ProGit book is imported from the [progit/progit2](https://github.com/progit/progit2) repository, which is available under a Creative Commons [CC-BY-NC-SA](https://creativecommons.org/licenses/by-nc-sa/3.0/) license, [ as specified in the progit2 repository](https://github.com/progit/progit2/blob/master/LICENSE.asc). Bug reports and suggestions on the technical content or English language version of the book should be made in the progit2 repository. Fixes for translated versions of the book should be made in the [ appropriate language-specific repository](https://github.com/progit/progit2/blob/master/TRANSLATING.md#helping-with-a-existing-project).
  * The reference manual is imported from the Git project, and is available under the [GPL](https://github.com/git/git/blob/master/COPYING). Bug reports and suggestions should be made to the upstream [Git community](https://git-scm.com/community).
  * Bugs in the Git software itself should similarly go to the [Git community](https://git-scm.com/community).


## Authors
This site was originally conceived and written by [Scott Chacon](https://github.com/schacon). Much of the current visual design is the work of [Jason Long](https://github.com/jasonlong). The site is currently collaboratively maintained in the [git-scm.com](https://github.com/git/git-scm.com) repository at GitHub.
Credit also goes to the many contributors, bug reporters, and maintainers over the years, both in this repository and in others from which we pull content. See the individual repository histories for a complete list.
## Sponsors
We are grateful to the companies which have donated resources and services to keep the site running, including:
  * [FusionAuth](https://fusionauth.io), whose annual donation to the Git project pays for the hosting costs of this website.
  * [Cloudflare](https://cloudflare.com)
  * [Bonsai](https://bonsai.io/)

For a detailed view of the site's network layout, see our [architecture document](https://github.com/git/git-scm.com/blob/gh-pages/ARCHITECTURE.md).
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
